@@ -1,6 +1,50 @@
+#' Plotting for icenReg Fits
+#' @param x icenReg fit
+#' @param y new data.frame
+#' @param newdata new data.frame (ignored if \code{y} is included)
+#' @param fun Function to be plotted. Options include \code{"surv"} or \code{"cdf"}
+#' @param plot_legend Should legend be plotted?
+#' @param cis Should confidence/credible interval be plotted?
+#' @param ci_level Confidence/credible interval
+#' @param survRange Range of survival curve to be plotted
+#' @param evalPoints Number of evaluations of survival curve to be plotted. 
+#' @param lgdLocation Location of legend; see \code{?legend} for options
+#' @param xlab Label of x-axis
+#' @param ... additional arguments to be passed to the base \code{plot} function
+#' @details Plots survival function from either an \code{ic_np, ic_sp, ic_par} or \code{ic_bayes}
+#' object. If \code{newdata} is \code{NULL}, the baseline distribution is plotted. Otherwise,
+#'  \code{newdata} should be a \code{data.frame} with each row containing a set 
+#'  covariates for which the fit will be plotted. If multiple rows are included, 
+#'  the lines will be colored and a legend will be created using the rownames of \code{newdata}.
+#'  
+#'  For \code{ic_np} and \code{ic_sp}, the MLE is plotted with no intervals (at the time
+#'  of writing this, there is no formula for standard errors of baseline distributions 
+#'  for these methods). 
+#' 
+#'  For \code{ic_par} and \code{ic_bayes}, the output plotted is directly extracted from
+#'  \code{survCIs}.
+#'  
+#'  If the argument \code{col} is provided, it will be used to color each 
+#'  survival function in order of the rows provided in \code{newdata}.
+#'  
+#' @examples
+#'  # Fitting mice data set
+#'  data(miceData)
+#'  miceFit <- ic_par(cbind(l, u) ~ grp, data = miceData) 
+#'  
+#'  # Creating covariates we want plotted
+#'  newData <- data.frame(grp = c("ce", "ge"))
+#'  # Naming rows for legend
+#'  rownames(newData) <- c("Conventional", "Germ-Free")
+#'  
+#'  plot(miceFit, newdata = newData, 
+#'       col = c('blue', 'orange'))
+#' @export
 plot.icenReg_fit <- function(x, y, newdata = NULL, fun = 'surv', 
                              plot_legend = T,
                              cis = T, ci_level = 0.9,
+                             survRange = c(0.025, 1), 
+                             evalPoints = 200,
                              lgdLocation = 'topright', 
                              xlab = "time", ...){
   if(inherits(x, 'impute_par_icph'))	stop('plot currently not supported for imputation model')
@@ -34,8 +78,9 @@ plot.icenReg_fit <- function(x, y, newdata = NULL, fun = 'surv',
     
   }
   else if(inherits(x, 'par_fit') | inherits(x, 'bayes_fit')){
+    pRange = 1 - survRange
     ranges <- matrix(nrow = nRows, ncol = 2)
-    surv_est <- survCIs(x, newdata, p = c(0.025, 0.975))
+    surv_est <- survCIs(x, newdata, p = pRange)
     xmin = Inf
     xmax = -Inf
     for(i in seq_along(surv_est)){
@@ -59,8 +104,9 @@ plot.icenReg_fit <- function(x, y, newdata = NULL, fun = 'surv',
   newLinesList$cis = cis
   newLinesList$ci_level = ci_level
   newLinesList$col = colors
-  do.call(lines, newLinesList)
-  # lines(x, newdata, cis = cis, ci_level = ci_level,...)
+  newLinesList$evalPoints = evalPoints
+  newLinesList$survRange = survRange
+  do.call(lines.icenReg_fit, newLinesList)
   if(nRows > 1 & plot_legend){
     grpNames <- rownames(newdata)
     legend(lgdLocation, legend = grpNames, lwd = rep(1, length(grpNames) ), col = colors)
@@ -70,9 +116,13 @@ plot.icenReg_fit <- function(x, y, newdata = NULL, fun = 'surv',
 lines.surv_cis <- function(x, col, include_cis = T, ...){ 
   x$all_lines(col = col, include_cis = include_cis, ...) }
 
+#' @inherit plot.icenReg_fit
+#' @export
 lines.icenReg_fit <- function(x, y, newdata = NULL, 
                               fun = 'surv', cis = F, 
-                              ci_level = 0.9, ...){
+                              ci_level = 0.9, 
+                              survRange = c(0.025, 1), 
+                              evalPoints = 20, ...){
   argList <- list(...)
   colors <- argList$col
   if(missing(y)) y <- newdata	
@@ -116,13 +166,17 @@ lines.icenReg_fit <- function(x, y, newdata = NULL,
     }
   }
   else if(inherits(x, 'par_fit') | inherits(x, 'bayes_fit')){
-    cis_est <- survCIs(x, newdata)
+    pRange = 1 - survRange
+    p_eval = pRange[1] + (pRange[2] - pRange[1]) * (0:evalPoints) / evalPoints
+    cis_est <- survCIs(x, newdata, p = p_eval)
     argList <- list(...)
     argList$col = NULL
     argList$x = cis_est
     argList$col = colors
     argList$include_cis = cis
-    do.call(lines, argList)
+    argList$evalPoints = NULL
+    argList$survRange = NULL
+    do.call(lines.surv_cis, argList)
   }
 }
 
@@ -153,7 +207,8 @@ lines.ic_npList <- function(x, fitNames = NULL, ...){
   }
 }
 
-plot.ic_npList <- function(x, fitNames = NULL, lgdLocation = 'bottomleft', ... ){
+plot.ic_npList <- function(x, fitNames = NULL, lgdLocation = 'bottomleft',
+                           plot_legend = T, ... ){
   addList <- list(xlim = x$xRange,
                   ylim = c(0,1),
                   xlab = 'time', 
@@ -184,7 +239,8 @@ plot.ic_npList <- function(x, fitNames = NULL, lgdLocation = 'bottomleft', ... )
   dotList$fitNames = fitNames
   dotList$x <- x
   do.call(lines, dotList)
-  legend(lgdLocation, legend = grpNames, col = cols, lty = 1)
+  if(plot_legend)
+   legend(lgdLocation, legend = grpNames, col = cols, lty = 1)
 }
 
 lines.sp_curves <- function(x, sname = 'baseline',...){
